package com.clx.performance.service.impl;

import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.clx.order.enums.OrderEnum;
import com.clx.performance.common.MqWrapper;
import com.clx.performance.dao.vehiclewarn.VehicleWarnUserDao;
import com.clx.performance.model.vehiclewarn.VehicleWarnUser;
import com.clx.performance.param.mq.SendSmsNoticeParam;
import com.clx.performance.service.SendSmsService;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.core.MessageBuilder;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

import static com.clx.performance.constant.RabbitKeyConstants.NOTICE_SEND_SMS_QUEUE_EXCHANGE;
import static com.clx.performance.constant.RabbitKeyConstants.NOTICE_SEND_SMS_QUEUE_ROUTING_KEY;

/**
 * @ClassName SendSmsServiceImpl
 * @Description
 * @Author kavin
 * @Date 2024/11/6 10:14
 * @Version 1.0
 */
@Service
@Slf4j
@AllArgsConstructor
public class SendSmsServiceImpl implements SendSmsService {

    private final RabbitTemplate rabbitTemplate;
    private final VehicleWarnUserDao vehicleWarnUserDao;

    public void sendChildWarnConfigSmsNotice(Integer warnTypeCode,String smsTemplateCode){
        log.info("开始运单预警通知配置短信消息,短信模版code:{}",smsTemplateCode);
        List<String> targets = getTargets(warnTypeCode);
        SendSmsNoticeParam param = new SendSmsNoticeParam();
        param.setCode(smsTemplateCode);
        param.setMobileList(targets);
        Message body = MessageBuilder.withBody(JSON.toJSONString(new MqWrapper<>(param)).getBytes()).build();
        rabbitTemplate.send(NOTICE_SEND_SMS_QUEUE_EXCHANGE,NOTICE_SEND_SMS_QUEUE_ROUTING_KEY, body);
        log.info("结束运单预警通知配置短信消息,短信模版code:{},", smsTemplateCode);
    }


    private List<String> getTargets(int code){
        return vehicleWarnUserDao.listAllEnable()
                .stream()
                .filter(item -> JSONUtil.toList(item.getWarnTypeJson(), Integer.class).contains(code))
                .map(VehicleWarnUser::getMobile).collect(Collectors.toList());
    }
}
